CREATE OR replace PROCEDURE kuljettajasivu(kkoodi IN INTEGER)
IS
   cursor tyonantajat IS SELECT talli.nimi nimi,alkamisaika,loppumisaika,
     talli.koodi tkoodi
     FROM aika,talli,kuljettaja k
     WHERE k.koodi=kkoodi AND
     aika.tyyppi=(SELECT tyyppi FROM aikasuhteet WHERE ensimmainen='kuljettaja'
     AND toinen='talli') AND aika.ekakoodi=k.koodi AND 
     aika.tokakoodi=talli.koodi;
   
   cursor sarjatulokset IS SELECT kplu.sarja,sarja.vuosi,sarja.koodi,
     sum(pisteet) yhtp
     FROM kuljettaja k,talli,tallisarja,kilpailu kplu,aika,tulos,sarja
     WHERE  k.koodi=kkoodi AND
     tulos.kuljettaja=k.koodi AND
     tulos.kilpailu=kplu.koodi AND
     tallisarja.sarjakoodi=kplu.sarja AND 
     tallisarja.tallikoodi=talli.koodi AND 
     aika.tyyppi=(SELECT tyyppi FROM aikasuhteet 
     WHERE ensimmainen='kuljettaja' AND toinen='talli') AND
     aika.alkamisaika<kplu.aajo AND 
     (aika.loppumisaika IS NULL OR aika.loppumisaika>kplu.kilpailu)
     AND aika.ekakoodi=k.koodi AND sarja.koodi=kplu.sarja AND 
     aika.tokakoodi=talli.koodi
     GROUP BY kplu.sarja,sarja.vuosi,sarja.koodi
     ORDER BY sarja.vuosi DESC ;
   
   
   tyot tyonantajat%ROWTYPE;
   nautto sarjatulokset%ROWTYPE;
   kuski kuljettaja%ROWTYPE;
   tsarja INTEGER;
   counter INTEGER;
   TYPE taustavari IS TABLE OF VARCHAR2(20) INDEX BY binary_integer;
   taustat taustavari;
BEGIN
   
   SELECT * INTO kuski FROM kuljettaja WHERE koodi=kkoodi;
   -- Hieno kysely menossa olevan sarjan valinnaksi.
   BEGIN 
      SELECT k.sarja INTO tsarja FROM kilpailu k 
	WHERE ABS(sysdate-k.kilpailu)= (SELECT min(ABS(sysdate-a.kilpailu)) FROM
	kilpailu a );
   EXCEPTION
      WHEN no_data_found THEN
	tsarja:=NULL;
   END;
   
   taustat(2):='bgcolor=#99cccc';
   taustat(1):=NULL;
   
   otsikko(kuski.enimi||' '||kuski.snimi);
   
   htp.tableopen(NULL,NULL,NULL,NULL,'width=90% border=4');
   htp.tabledata('<a href=ops$kpalin.kalenteri?skoodi='||tsarja||'>Kalenteri</a>','center');
   htp.tabledata('<a href=ops$kpalin.sarjasivu?skoodi='||tsarja||'>Sarja</a>','center');
   htp.tabledata('<a href=ops$kpalin.tallit>Tallit</a>','center');
   htp.tabledata('<a href=ops$kpalin.uutiset>Uutiset</a>','center');
   htp.tableclose;
   htp.line;
   htp.tableopen;
   htp.tablerowopen;
   htp.tabledata('<img src='||kuski.kuvaurl||'>');
   htp.p('<TD>');
   htp.tableopen;
   htp.tablerowopen;
   htp.tabledata('Nimi:');
   htp.tabledata(kuski.enimi||' '||kuski.snimi);
   htp.tablerowclose;
   htp.tablerowopen;
   htp.tabledata('Syntymaika ja -paikka:');
   htp.tabledata(to_char(kuski.saika,'DD.MM.YYYY')||', '||kuski.spaikka);
   htp.tablerowclose;
   htp.tablerowopen;
   IF kuski.kaika IS NOT NULL THEN
      htp.tabledata('Kuolinaika ja -paikka:');
      htp.tabledata(to_char(kuski.kaika,'DD.MM.YYYY')||', '||kuski.kpaikka);
      htp.tablerowclose;
      htp.tablerowopen;
   END IF;
   htp.tabledata('Kansalaisuus:');
   htp.tabledata(kuski.kansalaisuus);
   htp.tablerowclose;
   htp.tablerowopen;
   htp.tabledata('Kotipaikka:');
   htp.tabledata(kuski.kotipaikka);
   htp.tableclose;
   htp.p('</td>');
   htp.tablerowclose;
   
   htp.tableclose;
   
   htp.line;
   htp.p('Vanhat tallipaikat:');
   htp.tableopen(NULL,'center',NULL,NULL,'width=50%');
   htp.tableheader('Alkoi');
   htp.tableheader('Pttyi');
   htp.tableheader('Talli');
   counter:=1;
   FOR tyot IN tyonantajat LOOP
      htp.tablerowopen;
      htp.tabledata(to_char(tyot.alkamisaika,'DD.MM.YYYY'),NULL,NULL,NULL,NULL,NULL,taustat(MOD(counter,2)+1));
      htp.tabledata(to_char(tyot.loppumisaika,'DD.MM.YYYY'),NULL,NULL,NULL,NULL,NULL,taustat(MOD(counter,2)+1));
      htp.tabledata('<a href=ops$kpalin.tallisivu?tkoodi='||tyot.tkoodi||'>'||
	tyot.nimi||'</a>',NULL,NULL,NULL,NULL,NULL,taustat(MOD(counter,2)+1));
      htp.tablerowclose;
      counter:=counter+1;
   END LOOP;
   htp.tableclose;
   htp.para;
   htp.line;
   htp.para;
   htp.p('Menestys Formula-1 sarjoissa:');
   htp.tableopen(NULL,'center',NULL,NULL,'width=50%');
   
   counter:=1;
   htp.tableheader('Sarja');
   htp.tableheader('Pisteet');
   FOR nautto IN sarjatulokset LOOP
      htp.tablerowopen;
      htp.tabledata('<a href=ops$kpalin.sarjasivu?skoodi='||nautto.koodi||'>'||
	nautto.vuosi||'</a>',NULL,NULL,NULL,NULL,NULL,taustat(MOD(counter,2)+1));
      htp.tabledata(nautto.yhtp,NULL,NULL,NULL,NULL,NULL,taustat(MOD(counter,2)+1));
      htp.tablerowclose;
      counter:=counter+1;
   END LOOP;
   htp.tableclose;
   
   paate;
EXCEPTION
   WHEN OTHERS THEN
     htp.p('<h3>Proseduuri kuljettajasivu suoritus pttyi virheeseen:</h3>');
     htp.p('<font color=red>'|| sqlerrm || '</font>');
END;
/
show errors
  GRANT execute ON kuljettajasivu TO www_user;
EXIT
